from prettyqt.qt import QtCore


class Thread(QtCore.QThread):
    pass
